@@ -1,11 +1,22 @@
 # -*- coding: utf-8 -*-
 
 """
-@see: U{SPARQL Specification<http://www.w3.org/TR/rdf-sparql-query/>}
-@authors: U{Ivan Herman<http://www.ivan-herman.net>}, U{Sergio Fernández<http://www.wikier.org>}, U{Carlos Tejo Alonso<http://www.dayures.net>}
-@organization: U{World Wide Web Consortium<http://www.w3.org>} and U{Foundation CTIC<http://www.fundacionctic.org/>}.
-@license: U{W3C® SOFTWARE NOTICE AND LICENSE<href="http://www.w3.org/Consortium/Legal/copyright-software">}
-@requires: U{RDFLib<http://rdflib.net>} package.
+
+..
+  Developers involved:
+
+  * Ivan Herman <http://www.ivan-herman.net>
+  * Sergio Fernández <http://www.wikier.org>
+  * Carlos Tejo Alonso <http://www.dayures.net>
+  * Alexey Zakhlestin <https://indeyets.ru/>
+
+  Organizations involved:
+
+  * `World Wide Web Consortium <http://www.w3.org>`_
+  * `Foundation CTIC <http://www.fundacionctic.org/>`_
+
+  :license: `W3C® Software notice and license <http://www.w3.org/Consortium/Legal/copyright-software>`_
+  :requires: `RDFLib <https://rdflib.readthedocs.io>`_ package.
 """
 
 import urllib.request, urllib.error, urllib.parse
@@ -19,31 +30,32 @@ class Value(object):
     """
     Class encapsulating a single binding for a variable.
 
-    @cvar URI: the string denoting a URI variable
-    @cvar Literal: the string denoting a Literal variable
-    @cvar TypedLiteral: the string denoting a typed literal variable
-    @cvar BNODE: the string denoting a blank node variable
-
-    @ivar variable: The original variable, stored for an easier reference
-    @type variable: string
-    @ivar value: Value of the binding
-    @type value: string
-    @ivar type: Type of the binding
-    @type type: string; one of  L{Value.URI}, L{Value.Literal}, L{Value.TypedLiteral}, or L{Value.BNODE}
-    @ivar lang: Language tag of the binding, or C{None} if not set
-    @type lang: string
-    @ivar datatype: Datatype of the binding, or C{None} if not set
-    @type datatype: string (URI)
+    :ivar variable: The original variable, stored for an easier reference.
+    :vartype variable: string
+    :ivar value: Value of the binding.
+    :vartype value: string
+    :ivar type: Type of the binding. One of :attr:`Value.URI`, :attr:`Value.Literal`, :attr:`Value.TypedLiteral`, or :attr:`Value.BNODE`.
+    :vartype type: string
+    :ivar lang: Language tag of the binding, or ``None`` if not set.
+    :vartype lang: string
+    :ivar datatype: Datatype of the binding, or ``None`` if not set. It is an URI.
+    :vartype datatype: string
     """
     URI = "uri"
+    """the string denoting a URI variable."""
     Literal = "literal"
+    """the string denoting a Literal variable."""
     TypedLiteral = "typed-literal"
+    """the string denoting a typed literal variable."""
     BNODE = "bnode"
+    """the string denoting a blank node variable."""
 
     def __init__(self, variable, binding):
         """
-        @param variable: the variable for that binding. Stored for an easier reference
-        @param binding: the binding dictionary part of the return result for a specific binding
+        :param variable: the variable for that binding. Stored for an easier reference.
+        :type variable: string
+        :param binding: the binding dictionary part of the return result for a specific binding.
+        :type binding: dict
         """
         self.variable = variable
         self.value = binding['value']
@@ -74,23 +86,28 @@ class Bindings(object):
     return value and instantiates a number of attributes that can be consulted directly. See
     the list of variables.
 
-    The U{Serializing SPARQL Query Results in JSON<http://www.w3.org/TR/rdf-sparql-json-res/>} explains the details of the
-    JSON return structures. Very succintly: the return data has "bindings", which means a list of dictionaries. Each
-    dictionary is a possible binding of the SELECT variables to L{Value} instances. This structure is made a bit
+    The `Serializing SPARQL Query Results in JSON <http://www.w3.org/TR/rdf-sparql-json-res/>`_ explains the details of the
+    JSON return structures. Very succinctly: the return data has "bindings", which means a list of dictionaries. Each
+    dictionary is a possible binding of the SELECT variables to :class:`Value` instances. This structure is made a bit
     more usable by this class.
 
-    @ivar fullResult: The original dictionary of the results, stored for an easier reference
-    @ivar head: Header part of the return, see the JSON return format document for details
-    @ivar variables: List of unbounds (variables) of the original query. It is an array of strings. None in the case of an ASK query
-    @ivar bindings: The final bindings: array of dictionaries, mapping variables to L{Value} instances.
-    (If unbound, then no value is set in the dictionary; that can be easily checked with
-    C{var in res.bindings[..]}, for example.)
-    @ivar askResult: by default, set to False; in case of an ASK query, the result of the query
-    @type askResult: Boolean
+    :ivar fullResult: The original dictionary of the results, stored for an easier reference.
+    :vartype fullResult: dict
+    :ivar head: Header part of the return, see the JSON return format document for details.
+    :vartype head: dict
+    :ivar variables: List of unbounds (variables) of the original query. It is a list of strings. ``None`` in the case of an ASK query.
+    :vartype variables: list
+    :ivar bindings: The final bindings: list of dictionaries, mapping variables to :class:`Value` instances. \
+    If unbound, then no value is set in the dictionary; that can be easily checked with \
+    ``var in res.bindings[..]``, for example.
+    :vartype bindings: list
+    :ivar askResult: by default, set to **False**; in case of an ASK query, the result of the query.
+    :vartype askResult: bool
     """
     def __init__(self, retval):
         """
-        @param retval: the query result, instance of a L{Wrapper.QueryResult}
+        :param retval: the query result.
+        :type retval: :class:`QueryResult<SPARQLWrapper.Wrapper.QueryResult>`
         """
         self.fullResult = retval._convertJSON()
         self.head = self.fullResult['head']
@@ -122,9 +139,12 @@ class Bindings(object):
 
     def getValues(self, key):
         """A shorthand for the retrieval of all bindings for a single key. It is
-        equivalent to "C{[b[key] for b in self[key]]}"
-        @param key: possible variable
-        @return: list of L{Value} instances
+        equivalent to ``[b[key] for b in self[key]]``
+
+        :param key: possible variable name.
+        :type key: string
+        :return: list of :class:`Value` instances.
+        :rtype: list
         """
         try:
             return [b[key] for b in self[key]]
@@ -132,16 +152,16 @@ class Bindings(object):
             return []
 
     def __contains__(self, key):
-        """Emulation of the "C{key in obj}" operator. Key can be a string for a variable or an array/tuple
+        """Emulation of the "``key in obj``" operator. Key can be a string for a variable or an array/tuple
         of strings.
 
-        If C{key} is a variable, the return value is C{True} if there is at least one binding where C{key} is
-        bound. If C{key} is an array or tuple, the return value is C{True} if there is at least one binding
-        where I{all} variables in C{key} are bound.
+        If ``key`` is a variable, the return value is ``True`` if there is at least one binding where ``key`` is
+        bound. If ``key`` is an array or tuple, the return value is ``True`` if there is at least one binding
+        where *all* variables in ``key`` are bound.
 
-        @param key: possible variable, or array/tuple of variables
-        @return: whether there is a binding of the variable in the return
-        @rtype: Boolean
+        :param key: possible variable, or array/tuple of variables
+        :return: whether there is a binding of the variable in the return
+        :rtype: Boolean
         """
         if len(self.bindings) == 0:
             return False
@@ -167,23 +187,23 @@ class Bindings(object):
             return False
 
     def __getitem__(self, key):
-        """Emulation of the C{obj[key]} operator.  Slice notation is also available.
+        """Emulation of the ``obj[key]`` operator.  Slice notation is also available.
         The goal is to choose the right bindings among the available ones. The return values are always
-        arrays  of bindings, ie, arrays of dictionaries mapping variable keys to L{Value} instances.
+        arrays  of bindings, ie, arrays of dictionaries mapping variable keys to :class:`Value` instances.
         The different value settings mean the followings:
 
-         - C{obj[key]} returns the bindings where C{key} has a valid value
-         - C{obj[key1,key2,...]} returns the bindings where I{all} C{key1,key2,...} have valid values
-         - C{obj[(key1,key2,...):(nkey1,nkey2,...)]} returns the bindings where all C{key1,key2,...} have
-         valid values and I{none} of the C{nkey1,nkey2,...} have valid values
-         - C{obj[:(nkey1,nkey2,...)]} returns the bindings where I{none} of the C{nkey1,nkey2,...} have valid values
+         - ``obj[key]`` returns the bindings where ``key`` has a valid value
+         - ``obj[key1,key2,...]`` returns the bindings where *all* ``key1,key2,...`` have valid values
+         - ``obj[(key1,key2,...):(nkey1,nkey2,...)]`` returns the bindings where all ``key1,key2,...`` have
+         valid values and *none* of the ``nkey1,nkey2,...`` have valid values
+         - ``obj[:(nkey1,nkey2,...)]`` returns the bindings where *none* of the ``nkey1,nkey2,...`` have valid values
 
         In all cases complete bindings are returned, ie, the values for other variables, not present among
         the keys in the call, may or may not be present depending on the query results.
 
-        @param key: possible variable or array/tuple of keys with possible slice notation
-        @return: list of bindings
-        @rtype: array of variable -> L{Value}  dictionaries
+        :param key: possible variable or array/tuple of keys with possible slice notation
+        :return: list of bindings
+        :rtype: array of variable -> :class:`Value`  dictionaries
         """
         def _checkKeys(keys):
             if len(keys) == 0:
@@ -234,12 +254,12 @@ class Bindings(object):
         return retval
 
     def convert(self):
-        """This is just a convenience method, returns C{self}.
+        """This is just a convenience method, returns ``self``.
 
-        Although C{Binding} is not a subclass of L{QueryResult<SPARQLWrapper.Wrapper.QueryResult>}, it is returned as a result by
-        L{SPARQLWrapper2.query}, just like L{QueryResult<SPARQLWrapper.Wrapper.QueryResult>} is returned by
-        L{SPARQLWrapper.SPARQLWrapper.query}. Consequently,
-        having an empty C{convert} method to imitate L{QueryResult's convert method<SPARQLWrapper.Wrapper.QueryResult.convert>} may avoid unnecessary problems.
+        Although :class:`SPARQLWrapper2.Bindings` is not a subclass of :class:`SPARQLWrapper.QueryResult<SPARQLWrapper.Wrapper.QueryResult>`, it is returned as a result by
+        :func:`SPARQLWrapper2.query`, just like :class:`QueryResult<SPARQLWrapper.Wrapper.QueryResult>` is returned by
+        :func:`SPARQLWrapper.query()<SPARQLWrapper.Wrapper.SPARQLWrapper.query>`. Consequently,
+        having an empty :func:`convert` method to imitate :class:`QueryResult's convert() method<SPARQLWrapper.Wrapper.QueryResult.convert>` may avoid unnecessary problems.
         """
         return self
 
@@ -247,25 +267,32 @@ class Bindings(object):
 
 
 class SPARQLWrapper2(SPARQLWrapper.SPARQLWrapper):
-    """Subclass of L{Wrapper<SPARQLWrapper.SPARQLWrapper>} that works with a JSON SELECT return result only. The query result
-    is automatically set to a L{Bindings} instance. Makes the average query processing a bit simpler..."""
+    """Subclass of :class:`~SPARQLWrapper.Wrapper.SPARQLWrapper` that works with a JSON SELECT return result only. The query result
+    is automatically set to a :class:`Bindings` instance. Makes the average query processing a bit simpler..."""
     def __init__(self, baseURI, defaultGraph=None):
         """
-        Class encapsulating a full SPARQL call. In contrast to the L{SPARQLWrapper<SPARQLWrapper.SPARQLWrapper>} superclass, the return format
-        cannot be set (it is defaulted to L{JSON<Wrapper.JSON>}).
-        @param baseURI: string of the SPARQL endpoint's URI
-        @type baseURI: string
-        @param defaultGraph: URI for the default graph. Default is None, can be set via an explicit call, too
-        @type defaultGraph: string
+        Class encapsulating a full SPARQL call. In contrast to the :class:`~SPARQLWrapper.Wrapper.SPARQLWrapper` superclass, the return format
+        cannot be set (it is defaulted to :attr:`~SPARQLWrapper.Wrapper.SPARQLWrapper.JSON`).
+
+        :param baseURI: string of the SPARQL endpoint's URI.
+        :type baseURI: string
+        :param defaultGraph: URI for the default graph. Default is ``None``, can be set via an explicit call, too.
+        :type defaultGraph: string
         """
         super(SPARQLWrapper2, self).__init__(baseURI, returnFormat=JSON, defaultGraph=defaultGraph)
 
     def setReturnFormat(self, format):
-        """Set the return format (overriding the L{inherited method<SPARQLWrapper.SPARQLWrapper.setReturnFormat>}).
-        This method does nothing; this class instance should work with JSON only. The method is defined
-        just to avoid possible errors by erroneously setting the return format.
-        When using this class, the user can safely ignore this call.
-        @param format: return format
+        """
+        Set the return format (:meth:`overriding the inherited method <SPARQLWrapper.Wrapper.SPARQLWrapper.setReturnFormat>`).
+
+        .. warning::
+
+           This method does nothing; this class instance should work with JSON only. The method is defined \
+           just to avoid possible errors by erroneously setting the return format. \
+           When using this class, the user can safely ignore this call.
+
+        :param format: return format
+        :type format: string
         """
         pass
 
@@ -276,11 +303,11 @@ class SPARQLWrapper2(SPARQLWrapper.SPARQLWrapper):
             Exceptions can be raised if either the URI is wrong or the HTTP sends back an error.
             The usual urllib2 exceptions are raised, which cover possible SPARQL errors, too.
 
-            If the query type is I{not} SELECT, the method falls back to the
-            L{corresponding method in the superclass<SPARQLWrapper.query>}.
+            If the query type is *not* SELECT, the method falls back to the
+            :meth:`corresponding method in the superclass<SPARQLWrapper.Wrapper.SPARQLWrapper.query>`.
 
-            @return: query result
-            @rtype: L{Bindings} instance
+            :return: query result
+            :rtype: :class:`Bindings` instance
         """
         res = super(SPARQLWrapper2, self).query()
 
@@ -290,12 +317,12 @@ class SPARQLWrapper2(SPARQLWrapper.SPARQLWrapper):
             return res
 
     def queryAndConvert(self):
-        """This is here to override the inherited method; it is equivalent to L{query}.
+        """This is here to override the inherited method; it is equivalent to :class:`query`.
 
-        If the query type is I{not} SELECT, the method falls back to the
-        L{corresponding method in the superclass<SPARQLWrapper.queryAndConvert>}.
+        If the query type is *not* SELECT, the method falls back to the
+        :meth:`corresponding method in the superclass<SPARQLWrapper.Wrapper.SPARQLWrapper.queryAndConvert>`.
 
-        @return: the converted query result.
+        :return: the converted query result.
         """
         if self.queryType == SELECT:
             return self.query()
